.. _55jS-CU6BL:

=======================================
Subterranean
=======================================

Bunkers
=======================================

**The Emperor of Man - Warhammer 40K**

- https://youtu.be/KyPjE1Sn-Ts

Had an underground complex under the himalayan mountains that he used to build
up his forces for conquering the Earth from the various war lords and such.


Cities
=======================================

- `Ten Epic Underground Cities in Anime <https://myanimelist.net/featured/1786/Ten_Epic_Underground_Cities_in_Anime>`_

